pub fn conventions() -> Result<&'static Conventions, String>Expand description
The embedded conventions. Err means the embedded file is broken — pinned
by unit test, and propagated by the derivation paths rather than panicking.
pub fn conventions() -> Result<&'static Conventions, String>The embedded conventions. Err means the embedded file is broken — pinned
by unit test, and propagated by the derivation paths rather than panicking.